;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: ADCINC14.inc
;;  Version: 1.20, Updated on 2013/5/19 at 10:39:54
;;  Generated by PSoC Designer 5.4.2946
;;
;;  DESCRIPTION: Assembler declarations for the 8-bit ADCINC A/D Converter
;;               User Module with a 2nd-order modulator.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2013. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"

;--------------------------------------------------
; Constants for ADCINC14 API's.
;--------------------------------------------------

ADCINC14_OFF:                   equ 00h
ADCINC14_LOWPOWER:              equ 01h
ADCINC14_MEDPOWER:              equ 02h
ADCINC14_HIGHPOWER:             equ 03h

ADCINC14_bNUMBITS:             equ 0eh
ADCINC14_SIGNED_DATA:          equ 1
ADCINC14_9_OR_MORE_BITS:       equ ((0eh - 1)& 08h)
ADCINC14_8_OR_MORE_BITS:       equ ((0eh )& 08h)


;--------------------------------------------------
; Register Address Constants for ADCINC14
;--------------------------------------------------
ADCINC14_ISR_MASK:                     equ 02h
ADCINC14_ISR_REG:                      equ   0e1h
ADCINC14_CLR_REG:                      equ (((ADCINC14_ISR_REG & 038h)/8)^0dfh)


ADCINC14_PWMdr0:               equ 24h     ; Period reg
ADCINC14_PWMdr1:               equ 25h     ; Down count reg
ADCINC14_PWMdr2:               equ 26h     ; Compare reg
ADCINC14_PWMcr0:               equ 27h     ; Control reg
ADCINC14_PWMfn:                equ 24h     ; Function reg
ADCINC14_PWMsl:                equ 25h     ; Input  select reg
ADCINC14_PWMos:                equ 26h     ; Output select reg

ADCINC14_AtoD1cr0:             equ 0x80    ; SC Block 1 Control Reg 0
ADCINC14_AtoD1cr1:             equ 0x81    ; SC Block 1 Control Reg 1
ADCINC14_AtoD1cr2:             equ 0x82    ; SC Block 1 Control Reg 2
ADCINC14_AtoD1cr3:             equ 0x83    ; SC Block 1 Control Reg 3
ADCINC14_AtoD2cr0:             equ 0x90    ; SC Block 2 Control Reg 0
ADCINC14_AtoD2cr1:             equ 0x91    ; SC Block 2 Control Reg 1
ADCINC14_AtoD2cr2:             equ 0x92    ; SC Block 2 Control Reg 2
ADCINC14_AtoD2cr3:             equ 0x93    ; SC Block 2 Control Reg 3

ADCINC14_DEC_DL:               equ a1h     ; Decimator Low Data Reg
ADCINC14_DEC_DH:               equ a0h     ; Decimator High Data Reg

HighByte: equ 0
LowByte:  equ 1

macro ADCINC14_fIsDataAvailable_M
   RAM_SETPAGE_CUR >ADCINC14_fStatus
   mov A,[ADCINC14_fStatus]
endm


macro ADCINC14_iGetData_M
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >ADCINC14_iResult
   mov X,[(ADCINC14_iResult + HighByte)]
   mov A,[(ADCINC14_iResult + LowByte)]
   RAM_EPILOGUE RAM_USE_CLASS_4
endm


macro ADCINC14_wGetData_M
   ADCINC14_iGetData_M
endm


macro ADCINC14_cGetData_M
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >ADCINC14_iResult
   mov A,[(ADCINC14_iResult + LowByte)]
   RAM_EPILOGUE RAM_USE_CLASS_4
endm


macro ADCINC14_bGetData_M
   ADCINC14_cGetData_M
endm


macro ADCINC14_fClearFlag_M
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >ADCINC14_fStatus
   mov A,[ADCINC14_fStatus]
   mov [ADCINC14_fStatus],00h
   RAM_EPILOGUE RAM_USE_CLASS_4
endm


macro ADCINC14_iClearFlagGetData_M
   RAM_SETPAGE_CUR >ADCINC14_fStatus
  .repeat:
      mov [ADCINC14_fStatus],00h
      mov X,[(ADCINC14_iResult + HighByte)]
      mov A,[(ADCINC14_iResult + LowByte)]
      cmp [ADCINC14_fStatus],00h
  .until: jnz .repeat
endm


macro ADCINC14_wClearFlagGetData_M
   ADCINC14_iClearFlagGetData_M
endm


macro ADCINC14_cClearFlagGetData_M
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >ADCINC14_fStatus
   mov [ADCINC14_fStatus],00h
   mov A,[(ADCINC14_iResult + LowByte)]
   RAM_EPILOGUE RAM_USE_CLASS_4
endm


macro ADCINC14_bClearFlagGetData_M
   ADCINC14_cClearFlagGetData_M
endm


macro ADCINC14_ENABLE_INTEGRATOR_M  
   and reg[ADCINC14_AtoD1cr3],~10h
   and reg[ADCINC14_AtoD1cr2],~20h
   and reg[ADCINC14_AtoD2cr3],~10h
   and reg[ADCINC14_AtoD2cr2],~20h
endm


macro ADCINC14_RESET_INTEGRATOR_M  
   or  reg[ADCINC14_AtoD1cr2],20h
   or  reg[ADCINC14_AtoD1cr3],10h
   or  reg[ADCINC14_AtoD2cr2],20h
   or  reg[ADCINC14_AtoD2cr3],10h
endm


macro ADCINC14_STARTADC_M  
   ;Enable PWM interrupt 
   mov reg[ADCINC14_CLR_REG],~(ADCINC14_ISR_MASK)
   or  reg[ADCINC14_ISR_REG], (ADCINC14_ISR_MASK)
endm


macro ADCINC14_STOPADC_M
   ;Disable PWM interrupt  
   and reg[ADCINC14_ISR_REG],~(ADCINC14_ISR_MASK)
endm


macro ADCINC14_WritePulseWidth_M
    mov reg[ADCINC14_PWMdr2],A
endm

; end of file ADCINC14.inc
