;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: ADCINC14INT.asm
;;  Version: 1.20, Updated on 2013/5/19 at 10:39:54
;;
;;  DESCRIPTION: Assembler interrupt service routine for the ADCINC
;;               A/D Converter User Module. This code works for both the
;;               first and second-order modulator topologies.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2013. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "ADCINC14.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------

export _ADCINC14_ADConversion_ISR

export _ADCINC14_iResult
export  ADCINC14_iResult
export _ADCINC14_fStatus
export  ADCINC14_fStatus
export _ADCINC14_bState
export  ADCINC14_bState
export _ADCINC14_fMode
export  ADCINC14_fMode
export _ADCINC14_bNumSamples
export  ADCINC14_bNumSamples

;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------
AREA InterruptRAM(RAM,REL)
 ADCINC14_iResult:
_ADCINC14_iResult:                         BLK  2 ;Calculated answer
  iTemp:                                   BLK  2 ;internal temp storage
 ADCINC14_fStatus:
_ADCINC14_fStatus:                         BLK  1 ;ADC Status
 ADCINC14_bState:
_ADCINC14_bState:                          BLK  1 ;State value of ADC count
 ADCINC14_fMode:
_ADCINC14_fMode:                           BLK  1 ;Integrate and reset mode.
 ADCINC14_bNumSamples:
_ADCINC14_bNumSamples:                     BLK  1 ;Number of samples to take.

;-----------------------------------------------
;  EQUATES
;-----------------------------------------------

;@PSoC_UserCode_INIT@ (Do not change this line.)
;---------------------------------------------------
; Insert your custom declarations below this banner
;---------------------------------------------------

;------------------------
;  Constant Definitions
;------------------------


;------------------------
; Variable Allocation
;------------------------


;---------------------------------------------------
; Insert your custom declarations above this banner
;---------------------------------------------------
;@PSoC_UserCode_END@ (Do not change this line.)


AREA UserModules (ROM, REL)

;-----------------------------------------------------------------------------
;  FUNCTION NAME: _ADCINC14_ADConversion_ISR
;
;  DESCRIPTION: Perform final filter operations to produce output samples.
;
;-----------------------------------------------------------------------------
;
;    The decimation rate is established by the PWM interrupt. Four timer
;    clocks elapse for each modulator output (decimator input) since the
;    phi1/phi2 generator divides by 4. This means the timer period and thus
;    it's interrupt must equal 4 times the actual decimation rate.  The
;    decimator is ru  for 2^(#bits-6).
;
_ADCINC14_ADConversion_ISR:
    dec  [ADCINC14_bState]
if1:
    jc endif1 ; no underflow
    reti
endif1:
    cmp [ADCINC14_fMode],0
if2: 
    jnz endif2  ;leaving reset mode
    push A                            ;read decimator
    mov  A, reg[ADCINC14_DEC_DL]
    mov  [iTemp + LowByte],A
    mov  A, reg[ADCINC14_DEC_DH]
    mov  [iTemp + HighByte], A
    pop A
    mov [ADCINC14_fMode],1
    mov [ADCINC14_bState],((1<<(ADCINC14_bNUMBITS- 6))-1)
    reti
endif2:
    ;This code runs at end of integrate
    ADCINC14_RESET_INTEGRATOR_M
    push A
    mov  A, reg[ADCINC14_DEC_DL]
    sub  A,[iTemp + LowByte]
    mov  [iTemp +LowByte],A
    mov  A, reg[ADCINC14_DEC_DH]
    sbb  A,[iTemp + HighByte]

       ;check for overflow
IF     ADCINC14_8_OR_MORE_BITS
    cmp A,(1<<(ADCINC14_bNUMBITS - 8))
if3: 
    jnz endif3 ;overflow
    dec A
    mov [iTemp + LowByte],ffh
endif3:
ELSE
    cmp [iTemp + LowByte],(1<<(ADCINC14_bNUMBITS))
if4: 
    jnz endif4 ;overflow
    dec [iTemp + LowByte]
endif4:
ENDIF
IF ADCINC14_SIGNED_DATA
IF ADCINC14_9_OR_MORE_BITS
    sub A,(1<<(ADCINC14_bNUMBITS - 9))
ELSE
    sub [iTemp +LowByte],(1<<(ADCINC14_bNUMBITS - 1))
    sbb A,0
ENDIF
ENDIF
    mov  [ADCINC14_iResult + LowByte],[iTemp +LowByte]
    mov  [ADCINC14_iResult + HighByte],A
    mov  [ADCINC14_fStatus],1
ConversionReady:
    ;@PSoC_UserCode_BODY@ (Do not change this line.)
    ;---------------------------------------------------
    ; Insert your custom code below this banner
    ;---------------------------------------------------
    ;  Sample data is now in iResult
    ;
    ;  NOTE: This interrupt service routine has already
    ;  preserved the values of the A CPU register. If
    ;  you need to use the X register you must preserve
    ;  its value and restore it before the return from
    ;  interrupt.
    ;---------------------------------------------------
    ; Insert your custom code above this banner
    ;---------------------------------------------------
    ;@PSoC_UserCode_END@ (Do not change this line.)
    pop A
    cmp [ADCINC14_bNumSamples],0
if5: 
    jnz endif5 ; Number of samples is zero
    mov [ADCINC14_fMode],0
    mov [ADCINC14_bState],0
    ADCINC14_ENABLE_INTEGRATOR_M
    reti       
endif5:
    dec [ADCINC14_bNumSamples]
if6:
    jz endif6  ; count not zero
    mov [ADCINC14_fMode],0
    mov [ADCINC14_bState],0
    ADCINC14_ENABLE_INTEGRATOR_M
    reti       
endif6:
    ;All samples done

    M8C_SetBank1
    and reg[E7h], 3Fh            ; if we are in 29xxx or 24x94   
    or  reg[E7h], 80h            ; then set to full Alg. Mode
    M8C_SetBank0

    ADCINC14_STOPADC_M
 reti 
; end of file ADCINC14INT.asm
