;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: DelSigPlus12.asm
;;   Version: 1.10, Updated on 2013/5/19 at 10:43:14
;;  Generated by PSoC Designer 5.4.2946
;;
;;  DESCRIPTION: Assembler source for the Delta-Sigma A/D Converter User
;;               Module with 2nd-order modulator based on the Type 2 Decimator.
;;
;;  NOTE: User Module APIs conform to the fastcall16 convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API
;;        functions returns. For Large Memory Model devices it is also the
;;        caller's responsibility to preserve any value in the CUR_PP, IDX_PP,
;;        MVR_PP and MVW_PP registers. Even though some of these registers may
;;        not be modified now, there is no guarantee that will remain the case
;;        in future releases.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2013. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "DelSigPlus12.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export  DelSigPlus12_Start
export _DelSigPlus12_Start
export  DelSigPlus12_SetPower
export _DelSigPlus12_SetPower
export  DelSigPlus12_Stop
export _DelSigPlus12_Stop
export  DelSigPlus12_StartAD
export _DelSigPlus12_StartAD
export  DelSigPlus12_StopAD
export _DelSigPlus12_StopAD
export  DelSigPlus12_fIsDataAvailable
export _DelSigPlus12_fIsDataAvailable
export  DelSigPlus12_iGetDataClearFlag
export _DelSigPlus12_iGetDataClearFlag
export  DelSigPlus12_wGetDataClearFlag
export _DelSigPlus12_wGetDataClearFlag
export  DelSigPlus12_iGetData
export _DelSigPlus12_iGetData
export  DelSigPlus12_wGetData
export _DelSigPlus12_wGetData
export  DelSigPlus12_ClearFlag
export _DelSigPlus12_ClearFlag

;-----------------------------------------------
;  Constant Definitions
;-----------------------------------------------

CONTROL_REG_ENABLE_BIT:                    equ  01h     ; Control register start bit
POWERMASK:                                 equ  03h     ; Analog PSoC Block Power bits
MSB:                                       equ  0
LSB:                                       equ  1


AREA UserModules (ROM, REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DelSigPlus12_Start
;  FUNCTION NAME: DelSigPlus12_SetPower
;
;  DESCRIPTION: Applies power setting to the module's analog PSoc blocks.
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    The A register contains the power setting.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;                RAM use class 2: page pointer registers are not modified.
;
 DelSigPlus12_Start:
_DelSigPlus12_Start:
 DelSigPlus12_SetPower:
_DelSigPlus12_SetPower:
   RAM_PROLOGUE RAM_USE_CLASS_2
   mov  X, SP                                    ; Set up Stack frame
   and  A, POWERMASK                             ; Ensure value is legal
   push A
   mov  A, reg[DelSigPlus12_AtoD1cr3]            ; First SC block:
   and  A, ~POWERMASK                            ;   clear power bits to zero
   or   A, [ X ]                                 ;   establish new value
   mov  reg[DelSigPlus12_AtoD1cr3], A            ;   change the actual setting
   mov  A, reg[DelSigPlus12_AtoD2cr3]            ; Second SC block: as previous
   and  A, ~POWERMASK
   or   A, [ X ]
   mov  reg[DelSigPlus12_AtoD2cr3], A
   pop  A
   RAM_EPILOGUE RAM_USE_CLASS_2
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DelSigPlus12_Stop
;
;  DESCRIPTION:   Removes power from the module's analog PSoc blocks.
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;                RAM use class 1: page pointer registers are not modified.
;
 DelSigPlus12_Stop:
_DelSigPlus12_Stop:
   RAM_PROLOGUE RAM_USE_CLASS_1
   and  reg[DelSigPlus12_AtoD1cr3], ~POWERMASK
   and  reg[DelSigPlus12_AtoD2cr3], ~POWERMASK
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DelSigPlus12_StartAD
;
;  DESCRIPTION: Activates interrupts for this user module and begins sampling.
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;                RAM use class 1: page pointer registers may be modified.
;
 DelSigPlus12_StartAD:
_DelSigPlus12_StartAD:
   RAM_PROLOGUE RAM_USE_CLASS_1
   M8C_EnableIntMask DelSigPlus12_INT_REG, DelSigPlus12_INT_MASK
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DelSigPlus12_StopAD
;
;  DESCRIPTION: Shuts down the A/D by interrupt disabling. Analog power is
;               still supplied to the analog block.
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS: REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;                RAM use class 1: page pointer registers are not modified.
;
 DelSigPlus12_StopAD:
_DelSigPlus12_StopAD:
   RAM_PROLOGUE RAM_USE_CLASS_1
   M8C_DisableIntMask DelSigPlus12_INT_REG, DelSigPlus12_INT_MASK   ; Disable its interrupt
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DelSigPlus12_fIsDataAvailable
;
;  DESCRIPTION: Returns the status of the A/D Data
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall16 BOOL DataAvailable returned in the A register
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;    IN THE LARGE MEMORY MODEL CURRENTLY ONLY THE PAGE POINTER
;    REGISTERS LISTED BELOW ARE MODIFIED.  THIS DOES NOT GUARANTEE
;    THAT IN FUTURE IMPLEMENTATIONS OF THIS FUNCTION OTHER PAGE POINTER
;    REGISTERS WILL NOT BE MODIFIED.
;
;    Page Pointer Registers Modified:
;          CUR_PP
;
 DelSigPlus12_fIsDataAvailable:
_DelSigPlus12_fIsDataAvailable:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >DelSigPlus12_bfStatus
   mov  A, [DelSigPlus12_bfStatus]
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME:  DelSigPlus12_iGetDataClearFlag
;
;  DESCRIPTION:    Returns the data from the A/D.  Does not check if data is
;                  available. Also clears the DATA_READY flag.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall16 INT iData (LSB in A, MSB in X)
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;    IN THE LARGE MEMORY MODEL CURRENTLY ONLY THE PAGE POINTER
;    REGISTERS LISTED BELOW ARE MODIFIED.  THIS DOES NOT GUARANTEE
;    THAT IN FUTURE IMPLEMENTATIONS OF THIS FUNCTION OTHER PAGE POINTER
;    REGISTERS WILL NOT BE MODIFIED.
;
;    Page Pointer Registers Modified:
;          CUR_PP
;
;    UM interrupts are momentarily halted and restarted to
;    ensure data integrity.
;
 DelSigPlus12_iGetDataClearFlag:
_DelSigPlus12_iGetDataClearFlag:
 DelSigPlus12_wGetDataClearFlag:
_DelSigPlus12_wGetDataClearFlag:
   ; Note, data format is determined by the ISR.
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >DelSigPlus12_bfStatus
   M8C_DisableIntMask DelSigPlus12_INT_REG, DelSigPlus12_INT_MASK
   and  [DelSigPlus12_bfStatus], ~DelSigPlus12_DATA_READY_BIT
   mov  X, [DelSigPlus12_iResult+MSB]
   mov  A, [DelSigPlus12_iResult+LSB]
   M8C_EnableIntMask DelSigPlus12_INT_REG, DelSigPlus12_INT_MASK
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME:  DelSigPlus12_iGetData:
;
;  DESCRIPTION:     Returns the data from the A/D.  Does not check if data is
;                   available.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall16 INT iData (LSB in A, MSB in X)
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;    IN THE LARGE MEMORY MODEL CURRENTLY ONLY THE PAGE POINTER
;    REGISTERS LISTED BELOW ARE MODIFIED.  THIS DOES NOT GUARANTEE
;    THAT IN FUTURE IMPLEMENTATIONS OF THIS FUNCTION OTHER PAGE POINTER
;    REGISTERS WILL NOT BE MODIFIED.
;
;    Page Pointer Registers Modified:
;          CUR_PP
;
;    UM interrupts are momentarily halted and restarted to
;    ensure data integrity.
;
 DelSigPlus12_iGetData:
_DelSigPlus12_iGetData:
 DelSigPlus12_wGetData:
_DelSigPlus12_wGetData:
   ; Note, data format is determined by the ISR.
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >DelSigPlus12_iResult
   M8C_DisableIntMask DelSigPlus12_INT_REG, DelSigPlus12_INT_MASK
   mov  X, [DelSigPlus12_iResult+MSB]
   mov  A, [DelSigPlus12_iResult+LSB]
   M8C_EnableIntMask DelSigPlus12_INT_REG, DelSigPlus12_INT_MASK
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: DelSigPlus12_ClearFlag
;
;  DESCRIPTION: Clears the data ready flag.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;    IN THE LARGE MEMORY MODEL CURRENTLY ONLY THE PAGE POINTER
;    REGISTERS LISTED BELOW ARE MODIFIED.  THIS DOES NOT GUARANTEE
;    THAT IN FUTURE IMPLEMENTATIONS OF THIS FUNCTION OTHER PAGE POINTER
;    REGISTERS WILL NOT BE MODIFIED.
;
;    Page Pointer Registers Modified:
;          CUR_PP
;
 DelSigPlus12_ClearFlag:
_DelSigPlus12_ClearFlag:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >DelSigPlus12_bfStatus
   and  [DelSigPlus12_bfStatus], ~DelSigPlus12_DATA_READY_BIT
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION

; End of File DelSigPlus12.asm
