;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: DelSigPlus12INT.asm
;;   Version: 1.10, Updated on 2013/5/19 at 10:43:14
;;  Generated by PSoC Designer 5.4.2946
;;
;;  DESCRIPTION: Assembler interrupt service routine for the Delta-Sigma ADC
;;               User Module based on the Type 2 Decimator. This code works for
;;               both the first and second-order modulator topologies where
;;               the decimation rate requires no extra shift of the data
;;               in software.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2013. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "DelSigPlus12.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------

export _DelSigPlus12_ADC_ISR
export _DelSigPlus12_iResult
export  DelSigPlus12_iResult
export _DelSigPlus12_bfStatus
export  DelSigPlus12_bfStatus


;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------
AREA InterruptRAM (RAM, REL, CON)

_DelSigPlus12_iResult:
 DelSigPlus12_iResult:             blk 2             ;ADC output value
_DelSigPlus12_bfStatus:
 DelSigPlus12_bfStatus:            blk 1             ;Data Valid Flag


;-----------------------------------------------
;  Private Symbols
;-----------------------------------------------
MSB:                               equ 0
LSB:                               equ 1
RES:                               equ 14
UMAX:                              equ (1<<RES) - 1  ; 2^RES - 1


;@PSoC_UserCode_INIT@ (Do not change this line.)
;---------------------------------------------------
; Insert your custom declarations below this banner
;---------------------------------------------------

;------------------------
; Includes
;------------------------

;------------------------
; Exports
;------------------------

;------------------------
; Constant Definitions
;------------------------

;------------------------
; Variable Allocation
;------------------------

;---------------------------------------------------
; Insert your custom declarations above this banner
;---------------------------------------------------
;@PSoC_UserCode_END@ (Do not change this line.)


AREA UserModules (ROM, REL, CON)

;;=============================================================================
;;  FUNCTION NAME: _DelSigPlus12_ADC_ISR:
;;=============================================================================
;;
_DelSigPlus12_ADC_ISR:
   push  A
   mov   A, reg[DelSigPlus12_DEC_DH]
   cmp   A, >(UMAX+1)                            ; Is value >= 2^RES?
   jc    .NoOverflow                             ;    No, Data is in normal range
   mov   A, reg[DelSigPlus12_DEC_DL]
   mov   [DelSigPlus12_iResult+MSB], >UMAX       ;   Yes, limit to 2^RES - 1
   mov   [DelSigPlus12_iResult+LSB], <UMAX       ;          as expected
   jmp   .ConversionReady

.NoOverflow:
   mov   [DelSigPlus12_iResult+MSB], A
   mov   A, reg[DelSigPlus12_DEC_DL]
   mov   [DelSigPlus12_iResult+LSB], A

.ConversionReady:
IF DelSigPlus12_2S_COMPLEMENT
   ; Internal hardware format is unsigned; optionally convert so zero is half scale
   sub   [DelSigPlus12_iResult+MSB], >(UMAX+1)>>1
ENDIF
   mov [DelSigPlus12_bfStatus], DelSigPlus12_DATA_READY_BIT    

   ;@PSoC_UserCode_BODY@ (Do not change this line.)
   ;---------------------------------------------------
   ; Insert your custom code below this banner
   ;---------------------------------------------------


   ;---------------------------------------------------
   ; Insert your custom code above this banner
   ;---------------------------------------------------
   ;@PSoC_UserCode_END@ (Do not change this line.)

   pop A
   reti

; end of file DelSigPlus12INT.asm
