;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: ADCINC14.asm
;;   Version: 1.1, Updated on 2006/02/03 at 09:10:49
;;  Generated by PSoC Designer 5.4.2946
;;
;;  DESCRIPTION: Assembler source for the ADCINC A/D Converter
;;               User Module with 2nd-order modulator.
;;
;;  NOTE: User Module APIs conform to the fastcall16 convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API
;;        function returns. Even though these registers may be preserved now,
;;        there is no guarantee they will be preserved in future releases.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2013. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "ADCINC14.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export  ADCINC14_Start
export _ADCINC14_Start
export  ADCINC14_SetPower
export _ADCINC14_SetPower
export  ADCINC14_Stop
export _ADCINC14_Stop
export  ADCINC14_GetSamples
export _ADCINC14_GetSamples
export  ADCINC14_StopADC
export _ADCINC14_StopADC
export  ADCINC14_fIsDataAvailable
export _ADCINC14_fIsDataAvailable
export  ADCINC14_iClearFlagGetData
export _ADCINC14_iClearFlagGetData
export  ADCINC14_wClearFlagGetData
export _ADCINC14_wClearFlagGetData
export  ADCINC14_cClearFlagGetData
export _ADCINC14_cClearFlagGetData
export  ADCINC14_bClearFlagGetData
export _ADCINC14_bClearFlagGetData
export  ADCINC14_iGetData
export _ADCINC14_iGetData
export  ADCINC14_wGetData
export _ADCINC14_wGetData
export  ADCINC14_bGetData
export _ADCINC14_bGetData
export  ADCINC14_cGetData
export _ADCINC14_cGetData
export  ADCINC14_fClearFlag
export _ADCINC14_fClearFlag
export  ADCINC14_WritePulseWidth
export _ADCINC14_WritePulseWidth

AREA bss (RAM,REL)

;-----------------------------------------------
;  Constant Definitions
;-----------------------------------------------

;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------


AREA UserModules (ROM, REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_Start
;
;  DESCRIPTION: Applies power setting to the module's analog PSoc block.
;               and starts the PWM
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    The A register contains the power setting.
;  RETURNS:      Nothing.
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
 ADCINC14_Start:
_ADCINC14_Start:
   RAM_PROLOGUE RAM_USE_CLASS_1
   call  ADCINC14_SetPower
   ADCINC14_RESET_INTEGRATOR_M
   mov   reg[ADCINC14_PWMdr1],ffh
   or    reg[ADCINC14_PWMcr0],01h                    ; start PWM
   RAM_EPILOGUE RAM_USE_CLASS_1
 ret
.ENDSECTION

   
.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_SetPower
;
;  DESCRIPTION: Applies power setting to the module's analog PSoc block.
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    The A register contains the power setting.
;  RETURNS:      Nothing.
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
 ADCINC14_SetPower:
_ADCINC14_SetPower:
   RAM_PROLOGUE RAM_USE_CLASS_2
   and  A,03h                                    ; Ensure value is legal
   push A
   push A
   mov  X,SP                                     ; Set up Stack frame
   mov  A,reg[ADCINC14_AtoD1cr3]                 ; First SC block:
   and  A,~03h                                   ;   clear power bits to zero
   or   [ X - 2 ],A                              ;   save new va;ue on stack
   mov  A,reg[ADCINC14_AtoD2cr3]                 ; Second SC block:
   and  A,~03h                                   ;   clear power bits to zero
   or   [ X - 1 ],A                              ;   save new va;ue on stack
   pop  A
   mov  reg[ADCINC14_AtoD2cr3],A                 ; Write Second SC block
   pop  A
   mov  reg[ADCINC14_AtoD1cr3],A                 ; Write First SC block
   RAM_EPILOGUE RAM_USE_CLASS_2
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_Stop
;
;  DESCRIPTION:   Removes power from the module's analog PSoc block.
;                 and turns off PWM
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:     None.
;  RETURNS:       Nothing.
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
 ADCINC14_Stop:
_ADCINC14_Stop:
   RAM_PROLOGUE RAM_USE_CLASS_1
   ADCINC14_STOPADC_M 
   and  reg[ADCINC14_AtoD1cr3], ~03h
   and  reg[ADCINC14_AtoD2cr3], ~03h
   and  reg[ADCINC14_PWMcr0], ~01h ; stop PWM
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_GetSamples
;
;  DESCRIPTION: Activates interrupts for this user module and begins sampling.
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    A register contain number of samples/
;  RETURNS:      Nothing.
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
 ADCINC14_GetSamples:
_ADCINC14_GetSamples:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >ADCINC14_fMode
   ADCINC14_ENABLE_INTEGRATOR_M
   mov [ADCINC14_fMode],0
   mov [ADCINC14_bState],0
   mov [ADCINC14_bNumSamples],A
   mov A, reg[ADCINC14_PWMdr2]
   jnz  .SkipPulseWrite
   mov reg[ADCINC14_PWMdr2], 1
.SkipPulseWrite:

   M8C_SetBank1
   and reg[E7h], 3Fh             ; if we are in 29xxx or 24x94   
   or  reg[E7h], 40h             ; then set to incremental Mode
   M8C_SetBank0

   ADCINC14_STARTADC_M  ;enable interrupt
   RAM_EPILOGUE RAM_USE_CLASS_4 
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_StopAD
;
;  DESCRIPTION: Shuts down the A/D is an orderly manner.  The interrupt
;               is disabled but the PWM output is still active.
;               Integrator is reset
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
 ADCINC14_StopADC:
_ADCINC14_StopADC:
   RAM_PROLOGUE RAM_USE_CLASS_1

   M8C_SetBank1
   and reg[E7h], 3Fh             ; if we are in 29xxx or 24x94   
   or  reg[E7h], 80h             ; then set to full Alg. Mode
   M8C_SetBank0

   ADCINC14_STOPADC_M
   ADCINC14_RESET_INTEGRATOR_M
   RAM_EPILOGUE RAM_USE_CLASS_1 
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_fIsDataAvailable
;
;  DESCRIPTION: Returns the status of the A/D Data
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall BOOL DataAvailable returned in the A register
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
 ADCINC14_fIsDataAvailable:
_ADCINC14_fIsDataAvailable:
   RAM_PROLOGUE RAM_USE_CLASS_4
   ADCINC14_fIsDataAvailable_M     
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME:  ADCINC14_iClearFlagGetData
;				   ADCINC14_wClearFlagGetData

;  DESCRIPTION:    Clears the fStatus and places ADC data in iResult A/D.
;                  Flag is checked after trandfer to insure valid data.
;                  available. Also clears the DATA_READY flag. 
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall int iResult returned in the X and A register
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
 ADCINC14_iClearFlagGetData:
_ADCINC14_iClearFlagGetData:
 ADCINC14_wClearFlagGetData:
_ADCINC14_wClearFlagGetData:
   RAM_PROLOGUE RAM_USE_CLASS_4
   ADCINC14_iClearFlagGetData_M    
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret

.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME:  ADCINC14_cClearFlagGetData
;                  ADCINC14_bClearFlagGetData
;
;  DESCRIPTION:    Clears the fStatus and places ADC data in iResult A/D.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall int iResult returned in the X and A register
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
 ADCINC14_cClearFlagGetData:
_ADCINC14_cClearFlagGetData:
 ADCINC14_bClearFlagGetData:
_ADCINC14_bClearFlagGetData:
   RAM_PROLOGUE RAM_USE_CLASS_4
   ADCINC14_bClearFlagGetData_M    
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME:  ADCINC14_iGetData
;				   ADCINC14_wGetData

;  DESCRIPTION:     Returns the data from the A/D.  Does not check if data is
;                   available.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall int iResult is returned in the X,A registers
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
 ADCINC14_iGetData:
_ADCINC14_iGetData:
 ADCINC14_wGetData:
_ADCINC14_wGetData:
   RAM_PROLOGUE RAM_USE_CLASS_4
   ADCINC14_wGetData_M              
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME:  ADCINC14_bGetData
;				   ADCINC14_cGetData

;  DESCRIPTION:     Returns the data from the A/D.  Does not check if data is
;                   available.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      fastcall CHAR cData returned in the A register
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
 ADCINC14_bGetData:
_ADCINC14_bGetData:
 ADCINC14_cGetData:
_ADCINC14_cGetData:
   RAM_PROLOGUE RAM_USE_CLASS_4
   ADCINC14_cGetData_M              
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_fClearFlag
;
;  DESCRIPTION: Clears the data ready flag.
;-----------------------------------------------------------------------------
;  ARGUMENTS:    None.
;  RETURNS:      Nothing.
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;    
;    The DATA_READY flag is cleared.
;
 ADCINC14_fClearFlag:
_ADCINC14_fClearFlag:
   RAM_PROLOGUE RAM_USE_CLASS_4
   ADCINC14_fClearFlag_M              
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION


.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC14_WritePulseWidth
;
;  DESCRIPTION:
;     Write the 8-bit period value into the compare register (DR2).
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: fastcall BYTE bPeriodValue (passed in A)
;  RETURNS:   Nothing
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
 ADCINC14_WritePulseWidth:
_ADCINC14_WritePulseWidth:
   RAM_PROLOGUE RAM_USE_CLASS_1
   ADCINC14_WritePulseWidth_M
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

; End of File ADCINC14.asm
