//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

/*	=========================================
Serial two filters with envelop detection and filter reset. 

input => divide by 16 filter => Conditional divide by 64 with threhold at THRESHOLD => output right shifted by 10 bits => Gain term effected PER_GRAM
*	=========================================
*/

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include "PSoCGPIOINT.h"	// We have to include this file manually for GPIO
#include "string.h"

// PWM SPEED
#define PWM_PERIOD 100
// State machine states
#define BOOT 0
#define SETUP 1
#define WAITPAIRING 2
#define SENDADC 3
#define LEARNRFCODE 4
#define DEBUG 9
// ADC Moving Filter
#define FILTER1_DEPTH		16		// Filter Depth for first stage
#define FILTER2_DEPTH		16		// Filter Depth for second stage
#define THRESHOLD			13		//Noise threshold for reseting the filter stage 2
#define SHIFTER				4		// Final shift to accomodate all averagers result
#define DIVPERLBS			7		// 7 divisions = 1 lbs
// Motor
#define CW 1
#define CCW 0
#define STOP 0
#define FWD 1
#define RVS 2
#define SPEEDUP 1
#define SPEEDDOWN 0
// RF Input
#define RFNUMBEROFBYTES	20
#define RFPREAMBLE	0
#define RFADDRESS1	2
#define RFADDRESS2	6
#define RFADDRESS3	10
#define RFDATA	14
#define RFCRC	15
#define RFTAIL	17
#define HANDLE1_ADDRESS_OFFSET	0
#define HANDLE2_ADDRESS_OFFSET	4
#define PTREMOTE_ADDRESS_OFFSET	8
// COMMAND
#define ESTOP '1'
#define DOWN '2'
#define SPEEDM '3'
#define UP '4'
#define SPEEDP '5'
#define HOME '6'
#define TBD1 '7'
#define TBD2 '8'
#define TBD3 '9'

#pragma interrupt_handler GPIO_ISR

unsigned char state = SENDADC;
unsigned char prevstate = SENDADC;


void init(void);

void main(void)
{
	char * strPtr;                        // Parameter pointer	
	char * RFstrPtr;
	unsigned char waitresponse = 0;	
	unsigned char direction = 0;
	unsigned char RFADDRESS_Count = 0;
	unsigned char bError;
	signed long  Filter1_Result, Filter2_Result; 
	signed int ADC_Filter1[FILTER1_DEPTH];
	signed int ADC_Filter2[FILTER2_DEPTH];
	signed int ADC_prev_Value;
	int i = 0;
	int Ptr1 = 0;
	int Ptr2 = 0;
	
	M8C_EnableIntMask(INT_MSK0, INT_MSK0_GPIO);
	M8C_EnableGInt ; // Uncomment this line to enable Global Interrupts
	init();
	
//	state = LEARNRFCODE; // Debug state to develop code portions

	while(1) {
		switch (state){
			case SENDADC:
				if(ADCINC14_fIsDataAvailable()){
					ADC_Filter1[Ptr1] = ADCINC14_iClearFlagGetData();
					/* Simple moving average filter stage 1 */
					Filter1_Result=0;
					for(i=0;i<FILTER1_DEPTH;i++)
					{
						Filter1_Result += ADC_Filter1[i];
					}
					/* Wrapping around the Filter1 pointer */
					if(Ptr1++ == FILTER1_DEPTH)
					{
						Ptr1 = 0;
					}
					/* Providing first stage result to second stage current pointer */
					ADC_Filter2[Ptr2] = Filter1_Result >> SHIFTER;
					
					/* Second stage filter reset to current value of the change is more than noise threshold */
					if (((ADC_prev_Value - ADC_Filter2[Ptr2]) > THRESHOLD) || ((ADC_Filter2[Ptr2] - ADC_prev_Value) > THRESHOLD) && (ADC_Filter2[Ptr2] !=0))
					{ 
						for(i=0;i<FILTER2_DEPTH;i++)
						{
							ADC_Filter2[i] = ADC_Filter2[Ptr2];
						}
					}
					
					/* Simple moving average filter stage 2 */
					Filter2_Result=0;
					for(i=0;i<FILTER2_DEPTH;i++)
					{
						Filter2_Result += ADC_Filter2[i];
					}
					
					ADC_prev_Value = ADC_Filter2[Ptr2];
					
					/* Wrapping around the Filter2 pointer */
					if(Ptr2++ == FILTER2_DEPTH)
					{
						Ptr2 = 0;
					}
				
					/* Final shift to divide for moving average filters output shift */
					Filter2_Result = Filter2_Result >> SHIFTER;
					UART_DB_PutSHexInt((signed int)Filter2_Result);
					UART_DB_PutCRLF();
					UART_BT_CPutString("write ");
					UART_BT_PutSHexInt((signed int)Filter2_Result);
					UART_BT_CPutString(",");
					UART_BT_PutCRLF();
				}else {
					UART_DB_CPutString("No ADC data\r\n");
				}
				for(i=0; i<0xFFFF; i++){
				}
				break;
			default :
				break;
		}
   	}
}

void init(void ){
	COUNTER_RF_WritePeriod(64);
	COUNTER_RF_WriteCompareValue(32);
	COUNTER_RF_Start();
	
	UART_DB_CmdReset();                      	// Initialize receiver/cmd buffer
    UART_DB_IntCntl(UART_DB_ENABLE_RX_INT);     // Enable RX interrupts
	UART_DB_Start(UART_DB_PARITY_NONE);         // Enable UART

	UART_BT_CmdReset();                      	// Initialize receiver/cmd buffer
    UART_BT_IntCntl(UART_BT_ENABLE_RX_INT);     // Enable RX interrupts
	UART_BT_Start(UART_BT_PARITY_NONE);         // Enable UART
	
	UART_RF_CmdReset();                      	// Initialize receiver/cmd buffer
    UART_RF_IntCntl(UART_RF_ENABLE_RX_INT);     // Enable RX interrupts
	UART_RF_Start(UART_RF_PARITY_NONE);         // Enable UART
	
	PGA_SetGain(PGA_G1_00);						// Set PGA gain to 1
	PGA_Start(PGA_HIGHPOWER);					// Start PGA in high power

	ADCINC14_Start(ADCINC14_HIGHPOWER);
	ADCINC14_GetSamples(0);
	
	UART_DB_CPutString("ARX Debug Port V1.1 \r\n");
    UART_DB_CPutString("Booting...\r\n");   
}

void GPIO_ISR(void)
{

}
