//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

/*	=========================================
Serial two filters with envelop detection and filter reset. 

input => divide by 16 filter => Conditional divide by 64 with threhold at THRESHOLD => output right shifted by 10 bits => Gain term effected PER_GRAM
*	=========================================
*/

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include "PSoCGPIOINT.h"	// We have to include this file manually for GPIO
#include "string.h"

// PWM SPEED
#define PWM_PERIOD 100
// State machine states
#define BOOT 0
#define SETUP 1
#define WAITPAIRING 2
#define SENDADC 3
#define LEARNRFCODE 4
#define DEBUG 9
// ADC Moving Filter
#define FILTER1_DEPTH		16		// Filter Depth for first stage
#define FILTER2_DEPTH		16		// Filter Depth for second stage
#define THRESHOLD			13		//Noise threshold for reseting the filter stage 2
#define SHIFTER				4		// Final shift to accomodate all averagers result
#define DIVPERLBS			7		// 7 divisions = 1 lbs
// Motor
#define CW 1
#define CCW 0
#define STOP 0
#define FWD 1
#define RVS 2
#define SPEEDUP 1
#define SPEEDDOWN 0
// RF Input
#define RFNUMBEROFBYTES	20
#define RFPREAMBLE	0
#define RFADDRESS1	2
#define RFADDRESS2	6
#define RFADDRESS3	10
#define RFDATA	14
#define RFCRC	15
#define RFTAIL	17
#define HANDLE1_ADDRESS_OFFSET	0
#define HANDLE2_ADDRESS_OFFSET	4
#define PTREMOTE_ADDRESS_OFFSET	8
// COMMAND
#define ESTOP '1'
#define DOWN '2'
#define SPEEDM '3'
#define UP '4'
#define SPEEDP '5'
#define HOME '6'
#define TBD1 '7'
#define TBD2 '8'
#define TBD3 '9'

#pragma interrupt_handler GPIO_ISR

char ChooseMode[] = "Choose Mode>";		 																	// Command string to compare against
char Server[] = "Server>";		  																			// Command string to compare against
char Open[] = "open 1Server Opened: 1.";		  															// Command string to compare against
char LocalName[] = "setlocalname ARXBLUELocal Device Name: ARXBLUE.";		  								// Command string to compare against
char PinCodeReq[] = "atLinkKeyRequest:";		  															// Command string to compare against
char PinCodeReq2[] = "atPINCodeRequest:";		  															// Command string to compare against
char PinCodeRes[] = " with: PINCodeResponse";		  														// Command string to compare against
char PinCodeSuc[] = "PINCodeResponse 0000GAP_Authentication_Response(), Pin Code Response Success.";		// Command string to compare against
char writeFail[] = "Failed: -86.";
char FWD_Buffer[] = "FWD";
char RVS_Buffer[] = "RVS";
char Stop_Buffer[] = "stop";
char SpeedUpBuffer[] = "up";
char SpeedDownBuffer[] = "down";
char RFBuffer[RFNUMBEROFBYTES];
unsigned char state = SENDADC;
unsigned char prevstate = BOOT;
unsigned char MotorSpeed = PWM_PERIOD;

void init(void);
void activateBelt1(unsigned char direction);
void activateBelt2(unsigned char direction);
void SetMotorDir(unsigned char direction);
void SetMotorSpeed(unsigned char speed);
char CheckCRC(char* BufferPtr);
void RFDecode(char* BufferPtr);

void main(void)
{
	char * strPtr;                        // Parameter pointer	
	char * RFstrPtr;
	unsigned char waitresponse = 0;	
	unsigned char direction = 0;
	unsigned char RFADDRESS_Count = 0;
	unsigned char bError;
	signed long  Filter1_Result, Filter2_Result; 
	signed int ADC_Filter1[FILTER1_DEPTH];
	signed int ADC_Filter2[FILTER2_DEPTH];
	signed int ADC_prev_Value;
	int i = 0;
	int Ptr1 = 0;
	int Ptr2 = 0;
	
	M8C_EnableIntMask(INT_MSK0, INT_MSK0_GPIO);
	M8C_EnableGInt ; // Uncomment this line to enable Global Interrupts
	init();
	
//	state = LEARNRFCODE; // Debug state to develop code portions

	while(1) {
		switch (state){
			case BOOT:
//				if(UART_BT_bCmdCheck()) {                       // Wait for command  
//			    	UART_DB_PutString(UART_BT_szGetRestOfParams());      // Print out command 
//					UART_DB_PutCRLF();
//			      	UART_BT_CmdReset();                          // Reset command buffer  
//		   		}
		    	if(UART_BT_bCmdCheck()) {                       // Wait for command  
			    	strPtr = UART_BT_szGetRestOfParams();
					if (!(strncmp(strPtr,&ChooseMode[0],sizeof(&ChooseMode[0])))){
						state = SETUP;
						UART_DB_CPutString("Setup...\r\n");
					}
					UART_BT_CmdReset();
		   		}
				break;
			case SETUP:
				UART_BT_CPutString("Server\r\n");
				while (!waitresponse){
					if(UART_BT_bCmdCheck()) {                       // Wait for command  
				    	strPtr = UART_BT_szGetRestOfParams();
						if (!(strncmp(strPtr,&Server[0],sizeof(&Server[0])))){
							waitresponse = 1;
						}
						UART_BT_CmdReset();
		   			}
				}
				UART_DB_CPutString("Server Mode\r\n"); 
				waitresponse = 0;
				UART_BT_CPutString("setlocalname ARXBLUE\r\n");
				while (!waitresponse){
					if(UART_BT_bCmdCheck()) {                       // Wait for command  
				    	strPtr = UART_BT_szGetRestOfParams();
						if (!(strncmp(strPtr,&LocalName[0],sizeof(&LocalName[0])))){
							waitresponse = 1;
						}
						UART_BT_CmdReset();
		   			}
				}
				UART_DB_CPutString("ARXBLUE online\r\n"); 
				waitresponse = 0;
				UART_BT_CPutString("open 1\r\n");
				while (!waitresponse){
					if(UART_BT_bCmdCheck()) {                       // Wait for command  
				    	strPtr = UART_BT_szGetRestOfParams();
						if (!(strncmp(strPtr,&Open[0],sizeof(&Open[0])))){
							waitresponse = 1;
						}else {
							UART_BT_CPutString("open 1\r\n");
						}
						UART_BT_CmdReset();
		   			}
				}
				UART_DB_CPutString("Port Opened\r\n"); 
				state = WAITPAIRING;
				waitresponse = 0;
				UART_DB_CPutString("Wait Pairing...\r\n"); 
				break;
			case WAITPAIRING:
				while (!waitresponse){
					if(UART_BT_bCmdCheck()) {                       // Wait for command  
				    	strPtr = UART_BT_szGetRestOfParams();
						//UART_DB_PutString(strPtr);
						//UART_DB_PutCRLF();
						if (!(strncmp(strPtr,&PinCodeReq[0],sizeof(&PinCodeReq[0])))){
							waitresponse = 1;
						}
						UART_BT_CmdReset();
		   			}
				}
				UART_DB_CPutString("Pair Request Received\r\n");
				waitresponse = 0;
				while (!waitresponse){
					if(UART_BT_bCmdCheck()) {                       // Wait for command  
				    	strPtr = UART_BT_szGetRestOfParams();
					//	UART_DB_PutString(strPtr);
					//	UART_DB_PutCRLF();
						if ((!(strncmp(strPtr,&PinCodeRes[0],sizeof(&PinCodeRes[0])))) || (!(strncmp(strPtr,&PinCodeReq2[0],sizeof(&PinCodeReq2[0]))))){
							waitresponse = 1;
						}
						UART_BT_CmdReset();
		   			} 
				}
				waitresponse = 0;
				UART_BT_CPutString("PINCodeResponse 0000\r\n");
				while (!waitresponse){
					if(UART_BT_bCmdCheck()) {                       // Wait for command  
				    	strPtr = UART_BT_szGetRestOfParams();
					//	UART_DB_PutString(strPtr);
					//	UART_DB_PutCRLF();
						if (!(strncmp(strPtr,&PinCodeSuc[0],sizeof(&PinCodeSuc[0])))){
							waitresponse = 1;
						}else {
							UART_BT_CPutString("PINCodeResponse 0000\r\n");
						}
						UART_BT_CmdReset();
		   			}
				}
				UART_DB_CPutString("Pairing Success\r\n");
				state = SENDADC;
				break;
			case SENDADC:
				if(ADCINC14_fIsDataAvailable()){
					ADC_Filter1[Ptr1] = ADCINC14_iClearFlagGetData();
					/* Simple moving average filter stage 1 */
					Filter1_Result=0;
					for(i=0;i<FILTER1_DEPTH;i++)
					{
						Filter1_Result += ADC_Filter1[i];
					}
					/* Wrapping around the Filter1 pointer */
					if(Ptr1++ == FILTER1_DEPTH)
					{
						Ptr1 = 0;
					}
					/* Providing first stage result to second stage current pointer */
					ADC_Filter2[Ptr2] = Filter1_Result >> SHIFTER;
					
					/* Second stage filter reset to current value of the change is more than noise threshold */
					if (((ADC_prev_Value - ADC_Filter2[Ptr2]) > THRESHOLD) || ((ADC_Filter2[Ptr2] - ADC_prev_Value) > THRESHOLD) && (ADC_Filter2[Ptr2] !=0))
					{ 
						for(i=0;i<FILTER2_DEPTH;i++)
						{
							ADC_Filter2[i] = ADC_Filter2[Ptr2];
						}
					}
					
					/* Simple moving average filter stage 2 */
					Filter2_Result=0;
					for(i=0;i<FILTER2_DEPTH;i++)
					{
						Filter2_Result += ADC_Filter2[i];
					}
					
					ADC_prev_Value = ADC_Filter2[Ptr2];
					
					/* Wrapping around the Filter2 pointer */
					if(Ptr2++ == FILTER2_DEPTH)
					{
						Ptr2 = 0;
					}
				
					/* Final shift to divide for moving average filters output shift */
					Filter2_Result = Filter2_Result >> SHIFTER;
					UART_DB_PutSHexInt((signed int)Filter2_Result);
					UART_DB_PutCRLF();
					UART_BT_CPutString("write ");
					UART_BT_PutSHexInt((signed int)Filter2_Result);
					UART_BT_CPutString(",");
					UART_BT_PutCRLF();
				}else {
					UART_DB_CPutString("No ADC data\r\n");
				}
				for(i=0; i<0x4000; i++){
//					if(UART_BT_bCmdCheck()) {                       // Wait for command  
//				    	strPtr = UART_BT_szGetRestOfParams();
//						strPtr += 10;
//	//					UART_DB_PutString(strPtr);
//	//					UART_DB_PutCRLF();
//						if (!(strncmp(strPtr,&writeFail[0],sizeof(&writeFail[0])))){
//							state = WAITPAIRING;
//						}
//						UART_BT_CmdReset();
//		   			}
					if(UART_RF_bCmdCheck()) {                       // Wait for command  
						RFstrPtr = UART_RF_szGetRestOfParams();
						UART_RF_CmdReset();                          // Reset command buffer  
			   		}
					if (CheckCRC(RFstrPtr)){
						RFDecode(RFstrPtr);
						for (i=0;i<100;i++){
							UART_RF_CmdReset();
						}
						RFstrPtr = 0;
					}
				}
				break;
			case LEARNRFCODE:
//				UART_DB_CPutString("LEARNRFCODE state\r\n");
				if(UART_RF_bCmdCheck()) {                       // Wait for command  
					strPtr = UART_RF_szGetRestOfParams();
					UART_DB_PutString(strPtr);
					UART_DB_PutCRLF();
					UART_RF_CmdReset();                          // Reset command buffer  
		   		}
				if (CheckCRC(strPtr)){
					if (RFADDRESS_Count == 0){
						strPtr++;
						strPtr++;
						RFBuffer[RFADDRESS1] = *strPtr++;
						RFBuffer[RFADDRESS1+1] = *strPtr++;
						RFBuffer[RFADDRESS1+2] = *strPtr++;
						RFBuffer[RFADDRESS1+3] = *strPtr++;
						RFADDRESS_Count++;
						UART_DB_CPutString("Left Handle Learned\r\n");
						UART_DB_PutChar(RFBuffer[RFADDRESS1]);
						UART_DB_PutChar(RFBuffer[RFADDRESS1+1]);
						UART_DB_PutChar(RFBuffer[RFADDRESS1+2]);
						UART_DB_PutChar(RFBuffer[RFADDRESS1+3]);
						UART_DB_PutCRLF();
						for(i=0;i<100;i++){
							UART_RF_CmdReset();           // Reset command buffer
						}
					}else if (RFADDRESS_Count == 1){
						strPtr++;
						strPtr++;
						RFBuffer[RFADDRESS2] = *strPtr++;
						RFBuffer[RFADDRESS2+1] = *strPtr++;
						RFBuffer[RFADDRESS2+2] = *strPtr++;
						RFBuffer[RFADDRESS2+3] = *strPtr++;
						if ((RFBuffer[RFADDRESS1] != RFBuffer[RFADDRESS2]) || (RFBuffer[RFADDRESS1+1] != RFBuffer[RFADDRESS2+1]) || (RFBuffer[RFADDRESS1+2] != RFBuffer[RFADDRESS2+2]) || (RFBuffer[RFADDRESS1+3] != RFBuffer[RFADDRESS2+3])){
							RFADDRESS_Count++;
							UART_DB_CPutString("Right Handle Learned\r\n");
							UART_DB_PutChar(RFBuffer[RFADDRESS2]);
							UART_DB_PutChar(RFBuffer[RFADDRESS2+1]);
							UART_DB_PutChar(RFBuffer[RFADDRESS2+2]);
							UART_DB_PutChar(RFBuffer[RFADDRESS2+3]);
							UART_DB_PutCRLF();
							for(i=0;i<100;i++){
								UART_RF_CmdReset();           // Reset command buffer
							}
						}	
					}else if (RFADDRESS_Count == 2){
						strPtr++;
						strPtr++;
						RFBuffer[RFADDRESS3] = *strPtr++;
						RFBuffer[RFADDRESS3+1] = *strPtr++;
						RFBuffer[RFADDRESS3+2] = *strPtr++;
						RFBuffer[RFADDRESS3+3] = *strPtr++;
						if ((RFBuffer[RFADDRESS3] != RFBuffer[RFADDRESS2]) || (RFBuffer[RFADDRESS3+1] != RFBuffer[RFADDRESS2+1]) || (RFBuffer[RFADDRESS3+2] != RFBuffer[RFADDRESS2+2]) || (RFBuffer[RFADDRESS3+3] != RFBuffer[RFADDRESS2+3])){
							if ((RFBuffer[RFADDRESS3] != RFBuffer[RFADDRESS1]) || (RFBuffer[RFADDRESS3+1] != RFBuffer[RFADDRESS1+1]) || (RFBuffer[RFADDRESS3+2] != RFBuffer[RFADDRESS1+2]) || (RFBuffer[RFADDRESS3+3] != RFBuffer[RFADDRESS1+3])){
								bError = E2PROM_bE2Write(RFPREAMBLE, &RFBuffer[RFPREAMBLE], RFNUMBEROFBYTES, 25);		//write new serial number to EEPROM
								if (bError == E2PROM_NOERROR){
									PRT1DR |= LEARN_MASK;
									PRT2DR |= LEARN2_MASK;
									for(i=0;i<100;i++){
										UART_RF_CmdReset();           // Reset command buffer
									}
									M8C_EnableIntMask(INT_MSK0, INT_MSK0_GPIO);
									state = prevstate;
									RFADDRESS_Count = 0;
									UART_DB_CPutString("PT Remote Learned\r\n");
									UART_DB_PutChar(RFBuffer[RFADDRESS3]);
									UART_DB_PutChar(RFBuffer[RFADDRESS3+1]);
									UART_DB_PutChar(RFBuffer[RFADDRESS3+2]);
									UART_DB_PutChar(RFBuffer[RFADDRESS3+3]);
									UART_DB_PutCRLF();
									i = 0;
								}
							}
						}
					}
				}
				break;
			case DEBUG:
				if (i == 0){
					UART_DB_CPutString("Debug state\r\n");
					UART_DB_PutChar(RFBuffer[RFPREAMBLE]);
					UART_DB_PutChar(RFBuffer[RFPREAMBLE+1]);
					UART_DB_PutChar(RFBuffer[RFADDRESS1]);
					UART_DB_PutChar(RFBuffer[RFADDRESS1+1]);
					UART_DB_PutChar(RFBuffer[RFADDRESS1+2]);
					UART_DB_PutChar(RFBuffer[RFADDRESS1+3]);
					UART_DB_PutChar(RFBuffer[RFADDRESS2]);
					UART_DB_PutChar(RFBuffer[RFADDRESS2+1]);
					UART_DB_PutChar(RFBuffer[RFADDRESS2+2]);
					UART_DB_PutChar(RFBuffer[RFADDRESS2+3]);
					UART_DB_PutChar(RFBuffer[RFADDRESS3]);
					UART_DB_PutChar(RFBuffer[RFADDRESS3+1]);
					UART_DB_PutChar(RFBuffer[RFADDRESS3+2]);
					UART_DB_PutChar(RFBuffer[RFADDRESS3+3]);
					UART_DB_PutChar(RFBuffer[RFDATA]);
					UART_DB_PutChar(RFBuffer[RFCRC]);
					UART_DB_PutChar(RFBuffer[RFTAIL]);
					UART_DB_PutChar(RFBuffer[RFTAIL+1]);
					UART_DB_PutCRLF();
					i++;
				}else {
					if(UART_RF_bCmdCheck()) {                       // Wait for command  
						strPtr = UART_RF_szGetRestOfParams();
						UART_RF_CmdReset();                          // Reset command buffer  
			   		}
					if (CheckCRC(strPtr)){
						RFDecode(strPtr);
						for (i=0;i<100;i++){
							UART_RF_CmdReset();
						}
						strPtr = 0;
					}
//					if(UART_DB_bCmdCheck()) {                       // Wait for command  
//						strPtr = UART_DB_szGetRestOfParams();
//						UART_DB_CmdReset();                          // Reset command buffer  
//			   		}
//					if (!(strncmp(strPtr,&FWD_Buffer[0],sizeof(&FWD_Buffer[0])))){
//						SetMotorDir(FWD);
//						strPtr = 0;
//					}
//					if (!(strncmp(strPtr,&RVS_Buffer[0],sizeof(&RVS_Buffer[0])))){
//						SetMotorDir(RVS);
//						strPtr = 0;
//					}
//					if (!(strncmp(strPtr,&Stop_Buffer[0],sizeof(&Stop_Buffer[0])))){
//						SetMotorDir(STOP);
//						strPtr = 0;
//					}
//					if (!(strncmp(strPtr,&SpeedUpBuffer[0],sizeof(&SpeedUpBuffer[0])))){
//						SetMotorSpeed(SPEEDUP);
//						strPtr = 0;
//					}
//					if (!(strncmp(strPtr,&SpeedDownBuffer[0],sizeof(&SpeedDownBuffer[0])))){
//						SetMotorSpeed(SPEEDDOWN);
//						strPtr = 0;
//					}
				}
				break;
			default :
				break;
		}
//    	if(UART_BT_bCmdCheck()) {                       // Wait for command  
//	    	UART_DB_PutString(UART_BT_szGetRestOfParams());      // Print out command 
//			UART_DB_PutCRLF();
//	      	UART_BT_CmdReset();                          // Reset command buffer  
//   		}
//		if(UART_DB_bCmdCheck()) {                       // Wait for command  
//	    	UART_BT_PutString(UART_DB_szGetRestOfParams());             	// Print out command 
//			UART_BT_PutCRLF();
//	      	UART_DB_CmdReset();                          // Reset command buffer  
//   		} 
   	}

}

void init(void ){
	COUNTER_RF_WritePeriod(64);
	COUNTER_RF_WriteCompareValue(32);
	COUNTER_RF_Start();
	
	UART_DB_CmdReset();                      	// Initialize receiver/cmd buffer
    UART_DB_IntCntl(UART_DB_ENABLE_RX_INT);     // Enable RX interrupts
	UART_DB_Start(UART_DB_PARITY_NONE);         // Enable UART

	UART_BT_CmdReset();                      	// Initialize receiver/cmd buffer
    UART_BT_IntCntl(UART_BT_ENABLE_RX_INT);     // Enable RX interrupts
	UART_BT_Start(UART_BT_PARITY_NONE);         // Enable UART
	
	UART_RF_CmdReset();                      	// Initialize receiver/cmd buffer
    UART_RF_IntCntl(UART_RF_ENABLE_RX_INT);     // Enable RX interrupts
	UART_RF_Start(UART_RF_PARITY_NONE);         // Enable UART
	
	PWM_SPD_WritePeriod(PWM_PERIOD);
	PWM_SPD_WritePulseWidth(MotorSpeed);
	PWM_SPD_Start();
	
	PGA_SetGain(PGA_G1_00);						// Set PGA gain to 1
	PGA_Start(PGA_HIGHPOWER);					// Start PGA in high power
	
//	DelSigPlus12_Start(DelSigPlus12_HIGHPOWER);	// Start ADC in high power
//	DelSigPlus12_StartAD();
	ADCINC14_Start(ADCINC14_HIGHPOWER);
	ADCINC14_GetSamples(0);
	
	UART_DB_CPutString("ARX Debug Port V1.1 \r\n");
    UART_DB_CPutString("Booting...\r\n");   
	
	E2PROM_E2Read(RFPREAMBLE, &RFBuffer[RFPREAMBLE], RFNUMBEROFBYTES);		// 2-3 16 bit Address						
	if ((RFBuffer[RFPREAMBLE] != 'A') || (RFBuffer[RFTAIL] != 'T')){
		UART_DB_CPutString("Init EEPROM\r\n");
		RFBuffer[RFPREAMBLE] = 'A';											//Init RF Buffer
		RFBuffer[RFPREAMBLE+1] = 'A';										// 0-1 Preamble
		RFBuffer[RFADDRESS1] = '0';
		RFBuffer[RFADDRESS1+1] = '0';
		RFBuffer[RFADDRESS1+2] = '0';
		RFBuffer[RFADDRESS1+3] = '0';
		RFBuffer[RFADDRESS2] = '0';
		RFBuffer[RFADDRESS2+1] = '0';
		RFBuffer[RFADDRESS2+2] = '0';
		RFBuffer[RFADDRESS2+3] = '0';
		RFBuffer[RFADDRESS3] = '0';
		RFBuffer[RFADDRESS3+1] = '0';
		RFBuffer[RFADDRESS3+2] = '0';
		RFBuffer[RFADDRESS3+3] = '0';
		RFBuffer[RFDATA] = '0';												// 4 Data
		RFBuffer[RFCRC] = '0';												// 5 CRC
		RFBuffer[RFTAIL] = 'T';												// 6-7 Tail
		RFBuffer[RFTAIL+1] = 'T';
		RFBuffer[RFTAIL+2] = 0;
		E2PROM_bE2Write(RFPREAMBLE, &RFBuffer[RFPREAMBLE], RFNUMBEROFBYTES, 25);
		prevstate = state;
		state = LEARNRFCODE;
	}else {
		UART_DB_CPutString("Loaded Buffer from EEPROM\r\n");
	}
}

void activateBelt1(unsigned char direction){
	PRT0DR &= ~BELT1CCW_MASK;
	PRT0DR &= ~BELT1CW_MASK;
	if (direction){	// Clockwise
		PRT0DR |= BELT1CW_MASK;
	}else {			// Counter Clockwise
		PRT0DR |= BELT1CCW_MASK;
	}
}

void activateBelt2(unsigned char direction){
	PRT0DR &= ~BELT2CCW_MASK;
	PRT0DR &= ~BELT2CW_MASK;
	if (direction){	// Clockwise
		PRT0DR |= BELT2CW_MASK;
	}else {			// Counter Clockwise
		PRT0DR |= BELT2CCW_MASK;
	}
}

void SetMotorDir(unsigned char direction){
	switch (direction){
		case STOP: 
			PRT1DR &= ~FORWARD_MASK;
			PRT1DR &= ~REVERSE_MASK;
			UART_DB_CPutString("Stop\r\n");
			break;
		case FWD:
			PRT1DR &= ~REVERSE_MASK;
			PRT1DR |= FORWARD_MASK;
			UART_DB_CPutString("Forward\r\n");
			break;
		case RVS:
			PRT1DR &= ~FORWARD_MASK;
			PRT1DR |= REVERSE_MASK;
			UART_DB_CPutString("Reverse\r\n");
			break;
		default:
			break;
	}
}

void SetMotorSpeed(unsigned char speed){
	if (speed == SPEEDDOWN){
		if (MotorSpeed >= PWM_PERIOD){
			MotorSpeed = PWM_PERIOD;
		}else {
			MotorSpeed += PWM_PERIOD/10;
		}
		UART_DB_CPutString("SPEEDDOWN\r\n");
	}else if (speed == SPEEDUP){
		if (MotorSpeed <= 0){
			MotorSpeed = 0;
		}else{
			MotorSpeed -= PWM_PERIOD/10;
		}
		UART_DB_CPutString("SPEEDUP\r\n");
	}
	PWM_SPD_WritePulseWidth(MotorSpeed);
}

// Return 0 if string not valid
// Return 1 if string is valid
char CheckCRC(char* BufferPtr){
	char sum = 0;
	char CRC = 0;
	if (*BufferPtr == 'A' && *(BufferPtr + 9) == 'T'){
		BufferPtr++;
	}else {
		return 0;
	}
	if (*BufferPtr == 'A' && *(BufferPtr + 9) == 'T'){
		BufferPtr++;
	}else {
		return 0;
	}
	sum += *BufferPtr - 0x30;		//Address
	sum += *(BufferPtr+1) - 0x30;	//Address
	sum += *(BufferPtr+2) - 0x30;	//Address
	sum += *(BufferPtr+3) - 0x30;	//Address
	sum += *(BufferPtr+4);			//Data
	CRC = *(BufferPtr+5) - 0x30;	//CRC
	CRC = CRC << 4;
	CRC |= (*(BufferPtr+6) - 0x30);	//CRC
	if (sum == CRC){
		return 1;
	}else{
		return 0;
	}
}

void RFDecode(char* BufferPtr){
	char Code = *(BufferPtr + 6);
	
	if ((RFBuffer[RFADDRESS1] == *(BufferPtr+2)) && (RFBuffer[RFADDRESS1+1] == *(BufferPtr+3)) && (RFBuffer[RFADDRESS1+2] == *(BufferPtr+4)) && (RFBuffer[RFADDRESS1+3] == *(BufferPtr+5))){
		switch (Code){
			case ESTOP:
//				UART_DB_CPutString("EStop\r\n");
				SetMotorDir(STOP);
				break;
			case DOWN:
//				UART_DB_CPutString("Down\r\n");
				SetMotorDir(FWD);
				break;
			case SPEEDM:
//				UART_DB_CPutString("Speed -\r\n");
				SetMotorSpeed(SPEEDDOWN);
				break;
			case UP:
//				UART_DB_CPutString("Up\r\n");
				SetMotorDir(FWD);
				break;
			case SPEEDP:
//				UART_DB_CPutString("Speed +\r\n");
				SetMotorSpeed(SPEEDUP);
				break;
			case HOME:
				UART_DB_CPutString("Home\r\n");
				break;
			case TBD1:
				break;
			case TBD2:
				break;
			case TBD3:
				break;
			default:
				break;
		}
	}else if ((RFBuffer[RFADDRESS2] == *(BufferPtr+2)) && (RFBuffer[RFADDRESS2+1] == *(BufferPtr+3)) && (RFBuffer[RFADDRESS2+2] == *(BufferPtr+4)) && (RFBuffer[RFADDRESS2+3] == *(BufferPtr+5))){
		switch (Code){
			case ESTOP:
//				UART_DB_CPutString("EStop\r\n");
				SetMotorDir(STOP);
				break;
			case DOWN:
//				UART_DB_CPutString("Down\r\n");
				SetMotorDir(RVS);
				break;
			case SPEEDM:
//				UART_DB_CPutString("Speed -\r\n");
				SetMotorSpeed(SPEEDDOWN);
				break;
			case UP:
//				UART_DB_CPutString("Up\r\n");
				SetMotorDir(RVS);
				break;
			case SPEEDP:
//				UART_DB_CPutString("Speed +\r\n");
				SetMotorSpeed(SPEEDUP);
				break;
			case HOME:
				UART_DB_CPutString("Home\r\n");
				break;
			case TBD1:
				break;
			case TBD2:
				break;
			case TBD3:
				break;
			default:
				break;
		}
	}else if ((RFBuffer[RFADDRESS3] == *(BufferPtr+2)) && (RFBuffer[RFADDRESS3+1] == *(BufferPtr+3)) && (RFBuffer[RFADDRESS3+2] == *(BufferPtr+4)) && (RFBuffer[RFADDRESS3+3] == *(BufferPtr+5))){
//		UART_DB_CPutString("PT Remote\r\n");
		switch (Code){
			case ESTOP:
//				UART_DB_CPutString("EStop\r\n");
				SetMotorDir(STOP);
				break;
			case DOWN:
//				UART_DB_CPutString("Down\r\n");
				SetMotorDir(RVS);
				break;
			case SPEEDM:
//				UART_DB_CPutString("Speed -\r\n");
				SetMotorSpeed(SPEEDDOWN);
				break;
			case UP:
//				UART_DB_CPutString("Up\r\n");
				SetMotorDir(FWD);
				break;
			case SPEEDP:
//				UART_DB_CPutString("Speed +\r\n");
				SetMotorSpeed(SPEEDUP);
				break;
			case HOME:
				UART_DB_CPutString("Home\r\n");
				break;
			case TBD1:
				break;
			case TBD2:
				break;
			case TBD3:
				break;
			default:
				break;
		}
	}
}

void GPIO_ISR(void)
{
	if (!(PRT1DR & LEARN_MASK)){
		prevstate = state;
		state = LEARNRFCODE;
		M8C_DisableIntMask(INT_MSK0, INT_MSK0_GPIO);
	}
	if (!(PRT2DR & LEARN2_MASK)){
		prevstate = state;
		state = LEARNRFCODE;
		M8C_DisableIntMask(INT_MSK0, INT_MSK0_GPIO);
	}
}
